@@ -266,7 +266,7 @@ class dynEigenMat {
             
             viennacl::context ctx(viennacl::ocl::get_context(ctx_id));
             
-            viennacl::matrix<T> vclMat(K,M, ctx = ctx);
+            viennacl::matrix<T> vclMat(K,M, ctx);
             viennacl::copy(block, vclMat);
             
             return vclMat;
@@ -288,7 +288,7 @@ class dynEigenMat {
             
             viennacl::context ctx(viennacl::ocl::get_context(ctx_id));
             
-            viennacl::matrix<T> vclMat(K,M, ctx = ctx);
+            viennacl::matrix<T> vclMat(K,M, ctx);
             viennacl::copy(block, vclMat);
             
             return vclMat;
@@ -311,7 +311,7 @@ class dynEigenMat {
             
             viennacl::context ctx(viennacl::ocl::get_context(ctx_id));
             
-            shptr.reset(new viennacl::matrix<T>(K, M, ctx=ctx));
+            shptr.reset(new viennacl::matrix<T>(K, M, ctx));
             
             viennacl::copy(block, *shptr.get());
         };
@@ -330,7 +330,7 @@ class dynEigenMat {
             
             viennacl::context ctx(viennacl::ocl::get_context(ctx_id));
             
-            shptr.reset(new viennacl::matrix<T>(K, M, ctx=ctx));
+            shptr.reset(new viennacl::matrix<T>(K, M, ctx));
             
             viennacl::copy(block, *shptr.get());
         };
