@@ -1,6 +1,8 @@
 library(gpuR)
 context("CPU gpuMatrixBlock algebra")
 
+current_context <- set_device_context("cpu")
+
 # set seed
 set.seed(123)
 
@@ -236,6 +238,7 @@ test_that("CPU gpuMatrix Single Precision Scalar Matrix Division", {
 test_that("CPU gpuMatrix Single Precision Matrix Element-Wise Power", {
     
     has_cpu_skip()
+    pocl_check()
     
     AS = A[2:4, 2:4]
     BS = B[2:4, 2:4]
@@ -562,6 +565,7 @@ test_that("CPU gpuMatrix Double Precision Scalar Matrix Division", {
 test_that("CPU gpuMatrix Double Precision Matrix Element-Wise Power", {
     
     has_cpu_skip()
+    pocl_check()
     
     AS = A[2:4, 2:4]
     BS = B[2:4, 2:4]
@@ -664,3 +668,5 @@ test_that("CPU gpuMatrix Double Precision tcrossprod", {
                  info="double matrix elements not equivalent") 
     expect_error(crossprod(dgpuXS, dgpuZS))
 })
+
+setContext(current_context)
