@@ -1,6 +1,8 @@
 library(gpuR)
 context("CPU gpuMatrix Distance Computations")
 
+current_context <- set_device_context("cpu")
+
 # set seed
 set.seed(123)
 
@@ -314,3 +316,5 @@ test_that("CPU gpuMatrix Integer Precision Pairwise Squared Euclidean Distance",
               #              info="integer squared euclidean pairwise distances not equivalent",
               #              check.attributes=FALSE) 
           })
+
+setContext(current_context)
\ No newline at end of file
