@@ -11,7 +11,7 @@ if(detectGPUs() >= 1){
 set.seed(123)
 
 # ignore warnings (logs and arc trigs)
-options(warn=-1)
+# options(warn=-1)
 
 ORDER <- 4
 
