@@ -1,6 +1,12 @@
 library(gpuR)
 context("Switching GPU vclMatrixBlock algebra")
 
+if(detectGPUs() >= 1){
+    current_context <- set_device_context("gpu")    
+}else{
+    current_context <- currentContext()
+}
+
 # set seed
 set.seed(123)
 
@@ -936,3 +942,5 @@ test_that("Switching GPU vclMatrixBlock Double Precision tcrossprod", {
     expect_equal(currentContext(), 1L, 
                  info = "context index has been change unintentionally")
 })
+
+setContext(current_context)
