@@ -1,6 +1,12 @@
 library(gpuR)
 context("vclMatrix eigen decomposition")
 
+if(detectGPUs() >= 1){
+    current_context <- set_device_context("gpu")    
+}else{
+    current_context <- currentContext()
+}
+
 # set seed
 set.seed(123)
 
@@ -118,3 +124,4 @@ test_that("vclMatrix Symmetric Double Precision Matrix Eigen Decomposition",
 #                  info="float eigenvectors not equivalent")  
 # })
 
+setContext(current_context)
